@@ -1,17 +1,13 @@
 # Required PIL classes may or may not be available from the root namespace
 # depending on the installation method used.
 try:
-    import Image
-    import ImageFile
-    import ImageFilter
-    import ImageEnhance
-    import ImageColor
+    from PIL import Image, ImageColor, ImageEnhance, ImageFile, ImageFilter
 except ImportError:
     try:
-        from PIL import Image
-        from PIL import ImageFile
-        from PIL import ImageFilter
-        from PIL import ImageEnhance
-        from PIL import ImageColor
+        import Image
+        import ImageColor
+        import ImageEnhance
+        import ImageFile
+        import ImageFilter
     except ImportError:
-        raise ImportError('ImageKit was unable to import the Python Imaging Library. Please confirm it`s installed and available on your current Python path.')
\ No newline at end of file
+        raise ImportError('ImageKit was unable to import the Python Imaging Library. Please confirm it`s installed and available on your current Python path.')
